@@ -8,10 +8,10 @@ use warnings;
 use IO::Socket::SSL;
 use REST::Client;
 use Carp;
-use JSON::XS;
+use JSON::MaybeXS;
 use URI;    # The GET requests need URI-escaping
 
-our $VERSION = '0.03_02';
+our $VERSION = '0.03_03';
 
 sub new {
 	my ($class, %opts) = @_;
@@ -425,7 +425,7 @@ Pete Houston, C<< <cpan at openstrike.co.uk> >>
 
 Please report any bugs or feature requests to
 C<bug-webservice-abuseipdb at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.
+L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.
 See the file CONTRIBUTING.md for further details.
 
 =head1 ACKNOWLEDGEMENTS
@@ -435,7 +435,7 @@ API.
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright © 2020 Pete Houston.
+Copyright © 2020-2025 Pete Houston.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
